<?php
declare(strict_types=1);

namespace Flat101\EnhancedEcommerce\Plugin;

use Flat101\EnhancedEcommerce\Model\DataLayer\Generator\CheckoutStep;
use Flat101\EnhancedEcommerce\Model\DataLayer\Generator\CheckoutOptionStep;
use Flat101\EnhancedEcommerce\Model\DataLayer\CheckoutView;
use Flat101\EnhancedEcommerce\Model\Session AS CustomSession;
use Magento\Checkout\Api\Data\ShippingInformationInterface;
use Magento\Checkout\Model\ShippingInformationManagement;
use Magento\Quote\Api\CartRepositoryInterface;
use Magento\Customer\Model\Session AS CustomerModelSession;

class ShippingInformation
{
    const PAYMENT_STEP = 2;
    const PAYMENT_STEP_LABEL = 'step 2 - Payment info';

    /** @var CartRepositoryInterface */
    private $quoteRepository;

    /** @var CustomSession */
    private $customSession;

    /** @var CheckoutStep */
    private $checkoutStep;

    /** @var CheckoutOptionStep */
    private $checkoutOptionStep;

    /** @var CustomerModelSession */
    private $customerSession;

    public function __construct(
        CartRepositoryInterface $quoteRepository,
        CustomSession $customSession,
        CheckoutStep $checkoutStep,
        CheckoutOptionStep $checkoutOptionStep,
        CustomerModelSession $session
    ) {
        $this->quoteRepository = $quoteRepository;
        $this->customSession = $customSession;
        $this->checkoutStep = $checkoutStep;
        $this->checkoutOptionStep = $checkoutOptionStep;
        $this->customerSession = $session;
    }

    public function afterSaveAddressInformation(
        ShippingInformationManagement $object,
        $result,
        $cartId,
        ShippingInformationInterface $addressInformation
    ) {
        /** @var \Magento\Quote\Model\Quote $quote */
        $quote = $this->quoteRepository->getActive($cartId);

//        $registerOption = '';
//        if ($this->customerSession->isLoggedIn()) {
//            $registerOption = 'Login';
//        } else {
//            $registerOption = 'Guest';
//        }

        $this->customSession->setCheckoutStep(
            $this->checkoutOptionStep->onCheckoutOptionStep(CheckoutView::SHIPPING_STEP, $quote->getShippingAddress()->getShippingDescription())
        );

        $this->customSession->setCheckoutStep(
            $this->checkoutStep->onCheckoutStep(self::PAYMENT_STEP, null, self::PAYMENT_STEP_LABEL)
        );

        return $result;
    }
}
